charset_normalizer: The Real First Universal Charset Detector. Open, modern and actively maintained alternative to Chardet.
===========================================================================================================================

Description
-----------

The Real First Universal Charset Detector. Open, modern and actively maintained alternative to Chardet.

License
-------

MIT

Upstream Contact
----------------

https://pypi.org/project/charset-normalizer/

